create_agent

Function create_agent 

pub fn create_agent(model: &str, max_turns: u32) -> Agent
Create a new agent with the given model and max turns. This is a convenience function that matches the TypeScript SDK API. Create a new agent (alias for Agent::new)