pub fn load_command_from_file(
file_path: &Path,
plugin_name: &str,
plugin_source: &str,
is_skill: bool,
) -> Result<PluginCommand, AgentError>Expand description
Load a single plugin command from a markdown file
pub fn load_command_from_file(
file_path: &Path,
plugin_name: &str,
plugin_source: &str,
is_skill: bool,
) -> Result<PluginCommand, AgentError>Load a single plugin command from a markdown file