Module error_utils

Module error_utils 

API error utilities Extracts connection error details and formats API errors

Structs

ConnectionErrorDetails
Connection error details
NestedApiError
Shape of deserialized API errors from session JSONL

Functions

extract_connection_error_details_from_message
Extracts connection error details from an error message string
extract_nested_error_message
Extract a human-readable message from a deserialized API error
format_api_error
Format an API error for display
format_api_error_from_status
Format an API error from a status code and optional message
get_ssl_error_hint
Returns an actionable hint for SSL/TLS errors
sanitize_api_error
Detects if an error message contains HTML content