pub fn assert_installable_scope(scope: &str) -> Result<InstallableScope, String>Expand description
Assert that a scope is a valid installable scope at runtime
pub fn assert_installable_scope(scope: &str) -> Result<InstallableScope, String>Assert that a scope is a valid installable scope at runtime