pub struct RateLimiter { /* private fields */ }Expand description
Rate limiter that combines token bucket and sliding window
Implementations
Sourceimpl RateLimiter
impl RateLimiter
Sourcepub fn new(config: &RateLimitConfig) -> Self
pub fn new(config: &RateLimitConfig) -> Self
Create a new rate limiter
Sourcepub fn try_acquire(&mut self, token_count: u64) -> bool
pub fn try_acquire(&mut self, token_count: u64) -> bool
Try to acquire rate limit slot for a request with given token count
Sourcepub fn status(&self) -> RateLimitStatus
pub fn status(&self) -> RateLimitStatus
Get current status