pub fn is_auth_error(error: &AgentError) -> boolExpand description
Check if an error is an authentication failure (401) that should trigger client recreation / token refresh.
pub fn is_auth_error(error: &AgentError) -> boolCheck if an error is an authentication failure (401) that should trigger client recreation / token refresh.