pub fn enqueue_session_message(session_id: &str, message: &Message)Expand description
Enqueue a message for NDJSON streaming write.
This is the primary way to persist session messages incrementally. The global write queue will drain to disk every 100ms.