pub type Permutations<T> = T;Expand description
Permutations type in TypeScript generates all possible orderings of a union. In Rust, this doesn’t have a direct type-level equivalent, but can be implemented at runtime for enums.
pub type Permutations<T> = T;Permutations type in TypeScript generates all possible orderings of a union. In Rust, this doesn’t have a direct type-level equivalent, but can be implemented at runtime for enums.