Module abort_controller

Module abort_controller 

AbortController utilities

Structs

AbortController
AbortController implementation for Rust Provides similar functionality to the JavaScript AbortController
AbortSignal
AbortSignal implementation

Functions

create_abort_controller
Creates an AbortController with proper event listener limits set. This prevents MaxListenersExceededWarning when multiple listeners are attached to the abort signal.
create_abort_controller_default
Creates an AbortController with default max listeners
create_child_abort_controller
Creates a child AbortController that aborts when its parent aborts. Aborting the child does NOT affect the parent.

Type Aliases

AbortCallback