Module diff

Module diff 

Structured patch generation for file edits

Structs

StructuredPatchHunk
A single hunk from a structured diff

Constants

CONTEXT_LINES
Context lines around each hunk

Functions

count_lines_changed
Count lines added and removed from a structured patch.
generate_patch
Generate a structured patch from old and new file contents. Uses the similar crate for line-level diffing.