pub fn generate_patch(
old_content: &str,
new_content: &str,
) -> Vec<StructuredPatchHunk>Expand description
Generate a structured patch from old and new file contents.
Uses the similar crate for line-level diffing.
pub fn generate_patch(
old_content: &str,
new_content: &str,
) -> Vec<StructuredPatchHunk>Generate a structured patch from old and new file contents.
Uses the similar crate for line-level diffing.