pub fn clone_file_state_cache(cache: &FileStateCache) -> FileStateCacheExpand description
Helper function to clone a FileStateCache Preserves size limit configuration from the source cache
pub fn clone_file_state_cache(cache: &FileStateCache) -> FileStateCacheHelper function to clone a FileStateCache Preserves size limit configuration from the source cache