Module gitignore

Module gitignore 

Functions

add_file_glob_rule_to_gitignore
Adds a file pattern to the global gitignore file.
dir_is_in_git_repo
Checks if a directory is inside a git repo.
get_global_gitignore_path
Gets the path to the global gitignore file (.config/git/ignore)
is_path_gitignored
Checks if a path is ignored by git (via git check-ignore).