Module image_validation

Module image_validation 

Image validation utilities

Validates that all images in messages are within the API size limit.

Structs

ImageSizeError
Error thrown when one or more images exceed the API size limit
OversizedImage
Information about an oversized image

Constants

API_IMAGE_MAX_BASE64_SIZE
API image maximum base64 size (5MB)