Module model_validate

Module model_validate 

Model validation functions.

Translated from openclaudecode/src/utils/model/validateModel.ts

Structs

ModelValidationResult
Model validation result

Enums

ValidationError
Validation error types

Functions

validate_model
Validates a model by attempting an actual API call. This is an async function that would make an actual API call. In this stub, we provide a simplified synchronous version.