Module modifiers

Module modifiers 

Structs

Shortcut
A keyboard shortcut consisting of optional modifiers and a key.

Enums

Modifier
A keyboard modifier.
ModifierKey
Modifier key types.

Functions

is_modifier_pressed
Check if a specific modifier key is currently pressed. Note: This is a no-op on non-macOS platforms.
prewarm_modifiers
Pre-warm the native module by loading it in advance. Call this early to avoid delay on first use. Note: This is a no-op on non-macOS platforms.