Module cache_utils

Module cache_utils 

Functions

cleanup_orphaned_plugin_versions_in_background
Clean up orphaned plugin versions that have been orphaned for more than 7 days.
clear_all_caches
Clear all caches including non-plugin ones.
clear_all_plugin_caches
Clear all plugin-related caches.
mark_plugin_version_orphaned
Mark a plugin version as orphaned by writing a .orphaned_at timestamp file.