pub fn remove_plugin_installation(
plugin_id: &str,
scope: PluginScope,
project_path: Option<&str>,
)Expand description
Remove a plugin installation entry from a specific scope.
pub fn remove_plugin_installation(
plugin_id: &str,
scope: PluginScope,
project_path: Option<&str>,
)Remove a plugin installation entry from a specific scope.