Module plugin_identifier

Module plugin_identifier 

Structs

ParsedPluginIdentifier
Parsed plugin identifier with name and optional marketplace.

Functions

build_plugin_id
Build a plugin ID from name and marketplace.
is_official_marketplace_name
Check if a marketplace name is an official marketplace.
parse_plugin_identifier
Parse a plugin identifier string into name and marketplace components.
scope_to_setting_source
Map from installable plugin scope to editable setting source.
setting_source_to_scope
Convert an editable setting source to its corresponding plugin scope.