pub fn setting_source_to_scope(source: &str) -> Option<PluginScope>Expand description
Convert an editable setting source to its corresponding plugin scope.
pub fn setting_source_to_scope(source: &str) -> Option<PluginScope>Convert an editable setting source to its corresponding plugin scope.