Functions
- calculate_
plugin_ version - Calculate the version for a plugin based on its source.
- get_
git_ commit_ sha - Get the git commit SHA for a directory.
- get_
version_ from_ path - Extract version from a versioned cache path.
- is_
versioned_ path - Check if a path is a versioned plugin path.