Module zip_cache

Module zip_cache 

Functions

atomic_write_to_zip_cache
Write data to a file in the zip cache atomically.
cleanup_session_plugin_cache
Clean up the session plugin cache directory.
convert_directory_to_zip_in_place
Convert a plugin directory to a ZIP in-place.
create_zip_from_directory
Create a ZIP archive from a directory.
extract_zip_to_directory
Extract a ZIP file to a target directory.
get_marketplace_json_relative_path
Get the relative path for a marketplace JSON file within the zip cache.
get_plugin_zip_cache_path
Get the path to the zip cache directory.
get_session_plugin_cache_path
Get or create the session plugin cache directory.
get_zip_cache_installed_plugins_path
Get the path to installed_plugins.json in the zip cache.
get_zip_cache_known_marketplaces_path
Get the path to known_marketplaces.json in the zip cache.
get_zip_cache_marketplaces_dir
Get the marketplaces directory within the zip cache.
get_zip_cache_plugins_dir
Get the plugins directory within the zip cache.
is_marketplace_source_supported_by_zip_cache
Check if a marketplace source type is supported by zip cache mode.
is_plugin_zip_cache_enabled
Check if the plugin zip cache mode is enabled.