Module zip_cache_adapters

Module zip_cache_adapters 

Functions

read_marketplace_json
Read a marketplace JSON file from the zip cache.
read_zip_cache_known_marketplaces
Read known_marketplaces.json from the zip cache.
save_marketplace_json_to_zip_cache
Save a marketplace JSON to the zip cache from its install location.
sync_marketplaces_to_zip_cache
Sync marketplace data to zip cache for offline access.
write_zip_cache_known_marketplaces
Write known_marketplaces.json to the zip cache atomically.