Module render_options

Module render_options 

Structs

RenderOptions
Render options for the TUI.

Functions

get_base_render_options
Returns base render options, including stdin override when needed. Use this for all render calls to ensure piped input works correctly.