pub async fn sequential_with_index<T, R, F>(items: T, f: F) -> Vec<R>Expand description
Run async functions sequentially with index, waiting for each to complete.
pub async fn sequential_with_index<T, R, F>(items: T, f: F) -> Vec<R>Run async functions sequentially with index, waiting for each to complete.