pub fn evict_terminal_task(task_id: &str, set_app_state: &SetAppState)Expand description
Eagerly evict a terminal task from AppState. The task must be in a terminal state (completed/failed/killed) with notified=true.
pub fn evict_terminal_task(task_id: &str, set_app_state: &SetAppState)Eagerly evict a terminal task from AppState. The task must be in a terminal state (completed/failed/killed) with notified=true.