Agent

Struct Agent 

pub struct Agent { /* private fields */ }

Implementations

Source

impl Agent

pub fn new(model: &str, max_turns: u32) -> Self

Create a new agent with model name and max turns

pub fn with_event_callback<F>(model: &str, max_turns: u32, on_event: F) -> Self
where F: Fn(AgentEvent) + Send + Sync + 'static,

Create a new agent with model, max turns, and event callback for streaming

pub fn create(options: AgentOptions) -> Self

Create agent from AgentOptions

pub fn get_model(&self) -> &str

pub fn get_session_id(&self) -> &str

pub fn get_messages(&self) -> &[Message]

Get all messages in the conversation history

pub fn get_tools(&self) -> &[ToolDefinition]

Get all tools available to the agent

pub fn set_system_prompt(&mut self, prompt: &str)

Set system prompt for the agent

pub fn set_cwd(&mut self, cwd: &str)

Set the working directory for the agent

pub fn set_event_callback<F>(&mut self, callback: F)
where F: Fn(AgentEvent) + Send + Sync + 'static,

Set the event callback for agent events (tool start/complete/error, thinking, done) Note: This must be called BEFORE query() - it sets the callback on the engine

pub async fn execute_tool( &mut self, name: &str, input: Value, ) -> Result<ToolResult, AgentError>

Execute a tool directly (for testing/demo purposes)

pub async fn prompt(&mut self, prompt: &str) -> Result<QueryResult, AgentError>

Simple blocking prompt method - sends a prompt and returns the result. This matches the TypeScript SDK’s agent.prompt() API.

pub async fn query(&mut self, prompt: &str) -> Result<QueryResult, AgentError>