API error utilities Extracts connection error details and formats API errors
Structs
- Connection
Error Details - Connection error details
- Nested
ApiError - Shape of deserialized API errors from session JSONL
Functions
- extract_
connection_ error_ details_ from_ message - Extracts connection error details from an error message string
- extract_
nested_ error_ message - Extract a human-readable message from a deserialized API error
- format_
api_ error - Format an API error for display
- format_
api_ error_ from_ status - Format an API error from a status code and optional message
- get_
ssl_ error_ hint - Returns an actionable hint for SSL/TLS errors
- sanitize_
api_ error - Detects if an error message contains HTML content