Structs
- Resume
Config - Configuration for session resume.
- Resume
Result - Result of resuming a session.
- Session
Data - Session data on disk.
- Session
Entry - One line in the NDJSON transcript file.
- Session
Metadata - Session metadata.
- Session
Writer
Functions
- append_
session_ entry - Append one NDJSON session entry to the transcript file.
- append_
session_ message - Append a single message to the session as an NDJSON entry.
- append_
to_ session - Append a message to a session transcript.
- create_
preserved_ segment - Create a preserved segment from the last N messages.
- delete_
session - Delete a session.
- drain_
all_ sessions - Drain all pending session writes. Call on shutdown.
- enqueue_
session_ message - Enqueue a message for NDJSON streaming write.
- enqueue_
session_ metadata - Enqueue metadata for NDJSON streaming write.
- fork_
session - Fork a session (create a copy with a new ID).
- get_
jsonl_ path - Get the .jsonl path for a session’s NDJSON transcript.
- get_
session_ info - Get info about a specific session.
- get_
session_ messages - Get session messages.
- get_
session_ path - Get the path for a specific session.
- get_
sessions_ dir - Get the sessions directory path.
- get_
sidechain_ jsonl_ path - Get the sidechain .jsonl path for a subagent’s transcript within a session. Sidechain transcripts are stored as {session_id}/sidechains/{agent_id}.jsonl
- insert_
message_ chain - Insert a chain of messages into a session transcript.
- list_
sessions - List all sessions.
- load_
session - Load session from disk.
- load_
session_ jsonl - Load a session from its NDJSON transcript file.
- record_
sidechain_ transcript - Record a sidechain (subagent) transcript message.
- rename_
session - Rename a session.
- reset_
session_ globals_ for_ testing - Reset session globals for test isolation.
- resume_
session - Resume a session by loading its messages from disk.
- save_
session - Save session to disk.
- tag_
session - Tag a session.