Streaming tool executor that starts executing tools as they stream in from the API.
Translated from TypeScript StreamingToolExecutor.ts.
- Concurrent-safe tools can execute in parallel with other concurrent-safe tools
- Non-concurrent tools must execute alone (exclusive access)
- Results are buffered and emitted in the order tools were received
Re-exports
pub use crate::tools::orchestration::ToolMessageUpdate;
Structs
- Streaming
Tool Executor - Executes tools as they stream in with concurrency control.
Functions
- get_
tool_ concurrency_ info - Get tool concurrency info for the streaming executor.