Structs
- Command
Base - Base command shared by all command types.
- Command
Complete Options - Options for command completion.
- Local
Command - Local command definition.
- Local
JsxCommand - Local JSX command definition.
- Plugin
Info - Plugin info for a command.
- Prompt
Command - Prompt command configuration.
Enums
- Command
- Unified command enum combining base with specific implementation types.
- Command
Availability - Callback when a command declares who can use it (auth/provider requirement, static).
This is separate from
isEnabled(): - Command
Kind - Command kind enum.
- Command
Load Source - Where the command was loaded from.
- Command
Result Display - Command result display enum.
- Command
Source - Where a command was loaded from.
- Execution
Context - Execution context for commands.
- Local
Command Result - Local command result type.
- Resume
Entrypoint - Resume entry point.
- Setting
Source - Setting source enum.
Functions
- get_
command_ name - Resolves the user-visible name, falling back to
cmd.namewhen not overridden. - is_
command_ enabled - Resolves whether the command is enabled, defaulting to true.
Type Aliases
- Local
Command Module - Local command module shape.
- Local
JsxCommand Module - Local JSX command module shape.
- Local
JsxCommand OnDone - Callback when a command completes.