pub struct CommandBase {Show 17 fields
pub availability: Option<Vec<CommandAvailability>>,
pub description: String,
pub has_user_specified_description: Option<bool>,
pub is_enabled: Option<Box<dyn Fn() -> bool + Send + Sync>>,
pub is_hidden: Option<bool>,
pub name: String,
pub aliases: Option<Vec<String>>,
pub is_mcp: Option<bool>,
pub argument_hint: Option<String>,
pub when_to_use: Option<String>,
pub version: Option<String>,
pub disable_model_invocation: Option<bool>,
pub user_invocable: Option<bool>,
pub loaded_from: Option<CommandLoadSource>,
pub kind: Option<CommandKind>,
pub immediate: Option<bool>,
pub is_sensitive: Option<bool>,
}Expand description
Base command shared by all command types.
Fields
availability: Option<Vec<CommandAvailability>>description: Stringhas_user_specified_description: Option<bool>is_enabled: Option<Box<dyn Fn() -> bool + Send + Sync>>Defaults to true. Only set when the command has conditional enablement.
Defaults to false. Only set when the command should be hidden from typeahead/help.
name: Stringaliases: Option<Vec<String>>is_mcp: Option<bool>argument_hint: Option<String>when_to_use: Option<String>Detailed usage scenarios for when to use this command
version: Option<String>Version of the command/skill
disable_model_invocation: Option<bool>Whether to disable this command from being invoked by models
user_invocable: Option<bool>Whether users can invoke this skill by typing /skill-name
loaded_from: Option<CommandLoadSource>Where the command was loaded from
kind: Option<CommandKind>Distinguishes workflow-backed commands (badged in autocomplete)
immediate: Option<bool>If true, command executes immediately without waiting for a stop point
is_sensitive: Option<bool>If true, args are redacted from the conversation history