AbortController utilities
Structs
- Abort
Controller - AbortController implementation for Rust Provides similar functionality to the JavaScript AbortController
- Abort
Signal - AbortSignal implementation
Functions
- create_
abort_ controller - Creates an AbortController with proper event listener limits set. This prevents MaxListenersExceededWarning when multiple listeners are attached to the abort signal.
- create_
abort_ controller_ default - Creates an AbortController with default max listeners
- create_
child_ abort_ controller - Creates a child AbortController that aborts when its parent aborts. Aborting the child does NOT affect the parent.