Cursor utilities for text editing
Translated from openclaudecode/src/utils/Cursor.ts
Structs
- Yank
PopResult - Result from yank-pop operation
Statics
Functions
- can_
yank_ pop - Check if yank-pop is possible
- clear_
kill_ ring - Clear the kill ring
- get_
kill_ ring_ item - Get an item from the kill ring by index
- get_
kill_ ring_ size - Get the size of the kill ring
- get_
last_ kill - Get the last kill from the ring
- is_
vim_ punctuation - Check if character is Vim punctuation
- is_
vim_ whitespace - Check if character is whitespace
- is_
vim_ word_ char - Check if character is a Vim word character (letter, digit, underscore)
- push_
to_ kill_ ring - Push text to the kill ring
- record_
yank - Record a yank for yank-pop functionality
- reset_
kill_ accumulation - Reset kill accumulation state
- reset_
yank_ state - Reset yank state
- update_
yank_ length - Update the yank length
- yank_
pop - Perform yank-pop operation