Structured patch generation for file edits
Structs
- Structured
Patch Hunk - A single hunk from a structured diff
Constants
- CONTEXT_
LINES - Context lines around each hunk
Functions
- count_
lines_ changed - Count lines added and removed from a structured patch.
- generate_
patch - Generate a structured patch from old and new file contents.
Uses the
similarcrate for line-level diffing.