Functions
- add_
file_ glob_ rule_ to_ gitignore - Adds a file pattern to the global gitignore file.
- dir_
is_ in_ git_ repo - Checks if a directory is inside a git repo.
- get_
global_ gitignore_ path - Gets the path to the global gitignore file (.config/git/ignore)
- is_
path_ gitignored - Checks if a path is ignored by git (via
git check-ignore).