Image validation utilities
Validates that all images in messages are within the API size limit.
Structs
- Image
Size Error - Error thrown when one or more images exceed the API size limit
- Oversized
Image - Information about an oversized image
Constants
- API_
IMAGE_ MAX_ BASE64_ SIZE - API image maximum base64 size (5MB)