Structs
- Shortcut
- A keyboard shortcut consisting of optional modifiers and a key.
Enums
- Modifier
- A keyboard modifier.
- Modifier
Key - Modifier key types.
Functions
- is_
modifier_ pressed - Check if a specific modifier key is currently pressed. Note: This is a no-op on non-macOS platforms.
- prewarm_
modifiers - Pre-warm the native module by loading it in advance. Call this early to avoid delay on first use. Note: This is a no-op on non-macOS platforms.