Module loader

Module loader 

Plugin loader - cache-only loading functions

Ported from ~/claudecode/openclaudecode/src/utils/plugins/marketplaceManager.ts

This module provides cache-only loading functions for marketplaces and plugins. These functions are used for startup paths that should never block on network.

Structs

CachePluginResult
Result of caching a plugin.

Functions

cache_plugin
Cache a plugin and return the cached path.
clear_plugin_cache
Clear the plugin cache for a specific marketplace, or all if None.
get_known_marketplace_names
Get all known marketplace names
get_marketplace_cache_only
Get a marketplace by name from cache only (no network)
get_plugin_by_id_cache_only
Get a plugin by ID from cache only (no network)
get_plugin_cache_path
Get the plugin cache root directory.
get_versioned_cache_path
Get a versioned cache path for a specific plugin version.
get_versioned_zip_cache_path
Get a versioned zip cache path for a specific plugin version.
load_all_plugins
Load all plugins from cache (no network).
load_all_plugins_cache_only
Load all plugins from cache only (strictly no network).
parse_plugin_identifier
Parse plugin identifier into name and marketplace