Module loader

Module loader 

Plugin loader - cache-only loading functions

Ported from ~/claudecode/openclaudecode/src/utils/plugins/marketplaceManager.ts

This module provides cache-only loading functions for marketplaces and plugins. These functions are used for startup paths that should never block on network.

Functions

get_known_marketplace_names
Get all known marketplace names
get_marketplace_cache_only
Get a marketplace by name from cache only (no network)
get_plugin_by_id_cache_only
Get a plugin by ID from cache only (no network)
parse_plugin_identifier
Parse plugin identifier into name and marketplace