Structs
- Parsed
Plugin Identifier - Parsed plugin identifier with name and optional marketplace.
Functions
- build_
plugin_ id - Build a plugin ID from name and marketplace.
- is_
official_ marketplace_ name - Check if a marketplace name is an official marketplace.
- parse_
plugin_ identifier - Parse a plugin identifier string into name and marketplace components.
- scope_
to_ setting_ source - Map from installable plugin scope to editable setting source.
- setting_
source_ to_ scope - Convert an editable setting source to its corresponding plugin scope.