Functions
- atomic_
write_ to_ zip_ cache - Write data to a file in the zip cache atomically.
- cleanup_
session_ plugin_ cache - Clean up the session plugin cache directory.
- convert_
directory_ to_ zip_ in_ place - Convert a plugin directory to a ZIP in-place.
- create_
zip_ from_ directory - Create a ZIP archive from a directory.
- extract_
zip_ to_ directory - Extract a ZIP file to a target directory.
- get_
marketplace_ json_ relative_ path - Get the relative path for a marketplace JSON file within the zip cache.
- get_
plugin_ zip_ cache_ path - Get the path to the zip cache directory.
- get_
session_ plugin_ cache_ path - Get or create the session plugin cache directory.
- get_
zip_ cache_ installed_ plugins_ path - Get the path to installed_plugins.json in the zip cache.
- get_
zip_ cache_ known_ marketplaces_ path - Get the path to known_marketplaces.json in the zip cache.
- get_
zip_ cache_ marketplaces_ dir - Get the marketplaces directory within the zip cache.
- get_
zip_ cache_ plugins_ dir - Get the plugins directory within the zip cache.
- is_
marketplace_ source_ supported_ by_ zip_ cache - Check if a marketplace source type is supported by zip cache mode.
- is_
plugin_ zip_ cache_ enabled - Check if the plugin zip cache mode is enabled.