Functions
- read_
marketplace_ json - Read a marketplace JSON file from the zip cache.
- read_
zip_ cache_ known_ marketplaces - Read known_marketplaces.json from the zip cache.
- save_
marketplace_ json_ to_ zip_ cache - Save a marketplace JSON to the zip cache from its install location.
- sync_
marketplaces_ to_ zip_ cache - Sync marketplace data to zip cache for offline access.
- write_
zip_ cache_ known_ marketplaces - Write known_marketplaces.json to the zip cache atomically.