pub fn get_base_render_options(exit_on_ctrl_c: bool) -> RenderOptionsExpand description
Returns base render options, including stdin override when needed. Use this for all render calls to ensure piped input works correctly.
pub fn get_base_render_options(exit_on_ctrl_c: bool) -> RenderOptionsReturns base render options, including stdin override when needed. Use this for all render calls to ensure piped input works correctly.